"""Top-level package for mlsauce."""

__author__ = """T. Moudiki"""
__email__ = "thierry.moudiki@gmail.com"
__version__ = "__version__ = '0.2.1'"

from .adaopt.adaopt import AdaOpt

__all__ = ["AdaOpt"]
